==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/FullStochasticOscillatorIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { FullStochasticOscillatorIndicatorDescription } from "./FullStochasticOscillatorIndicatorDescription";
/**
 * @hidden
 */
export let FullStochasticOscillatorIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class FullStochasticOscillatorIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (FullStochasticOscillatorIndicatorDescriptionMetadata.a == null) {
                FullStochasticOscillatorIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FullStochasticOscillatorIndicatorDescriptionMetadata.c(FullStochasticOscillatorIndicatorDescriptionMetadata.a);
            }
            if (a.k(FullStochasticOscillatorIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.aa(FullStochasticOscillatorIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("Period", "Number:int");
            a.item("SmoothingPeriod", "Number:int");
            a.item("TriggerPeriod", "Number:int");
        }
        static d(a) {
            FullStochasticOscillatorIndicatorDescriptionMetadata.b(a);
            a.ac("FullStochasticOscillatorIndicator", () => new FullStochasticOscillatorIndicatorDescription());
            a.ab("FullStochasticOscillatorIndicator", FullStochasticOscillatorIndicatorDescriptionMetadata.a);
        }
    }
    FullStochasticOscillatorIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(FullStochasticOscillatorIndicatorDescriptionMetadata, 'FullStochasticOscillatorIndicatorDescriptionMetadata');
    FullStochasticOscillatorIndicatorDescriptionMetadata.a = null;
    return FullStochasticOscillatorIndicatorDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/FullStochasticOscillatorIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { FullStochasticOscillatorIndicatorDescription } from "./FullStochasticOscillatorIndicatorDescription";
/**
 * @hidden
 */
export let FullStochasticOscillatorIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class FullStochasticOscillatorIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (FullStochasticOscillatorIndicatorDescriptionMetadata.a == null) {
                FullStochasticOscillatorIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FullStochasticOscillatorIndicatorDescriptionMetadata.c(FullStochasticOscillatorIndicatorDescriptionMetadata.a);
            }
            if (a.k(FullStochasticOscillatorIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ac(FullStochasticOscillatorIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("Period", "Number:int");
            a.item("SmoothingPeriod", "Number:int");
            a.item("TriggerPeriod", "Number:int");
        }
        static d(a) {
            FullStochasticOscillatorIndicatorDescriptionMetadata.b(a);
            a.ae("FullStochasticOscillatorIndicator", () => new FullStochasticOscillatorIndicatorDescription());
            a.ad("FullStochasticOscillatorIndicator", FullStochasticOscillatorIndicatorDescriptionMetadata.a);
        }
    }
    FullStochasticOscillatorIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(FullStochasticOscillatorIndicatorDescriptionMetadata, 'FullStochasticOscillatorIndicatorDescriptionMetadata');
    FullStochasticOscillatorIndicatorDescriptionMetadata.a = null;
    return FullStochasticOscillatorIndicatorDescriptionMetadata;
})();
